INSTALLED_APPS = (
    'djexmo',
)
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': ':memory:',
    }
}
MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)
SECRET_KEY = "gloubiboulga secret key"
TEST_RUNNER = 'django.test.runner.DiscoverRunner'

NEXMO_API_KEY = 'API_KEY'
NEXMO_API_SECRET = 'SECRET'
NEXMO_DEFAULT_FROM = '+33123456789'



from django.utils.translation import ugettext as _


NEXMO_STATUSES = {
    "delivered": _("Message arrived to handset."),
    "expired": _("Message timed out after we waited 48h to receive status from mobile operator."),
    "failed": _("Message failed to be delivered."),
    "accepted": _("Message has been accepted by the mobile operator."),
    "submitted": _("Message has been accepted by the mobile operator."),
    "buffered": _("Message is being delivered."),
    "unknown": _("Un documented status from the mobile operator."),
}

UNKNOWN_STATUS = _('Unknown status')


NEXMO_MESSAGES = {
    0: _('Delivered'),
    1: _('Unknown error'),
    2: _('Absent Subscriber - Temporary'),
    3: _('Absent Subscriber - Permenant'),
    4: _('Call barred by user'),
    5: _('Portability Error'),
    6: _('Anti-Spam Rejection'),
    7: _('Handset Busy'),
    8: _('Network Error'),
    9: _('Illegal Number'),
    10: _('Invalid Message'),
    11: _('Unroutable'),
    99: _('General Error'),
}

UNKNOWN_MESSAGE = _('Unknown error')



import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.md')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-nexmo',
    version='2.0.0-alpha1',
    packages=['djexmo'],
    include_package_data=True,
    license='MIT',
    description='A simple Django app to send text messages using the Nexmo api.',
    long_description=README,
    url='https://github.com/thibault/django-nexmo',
    author='Thibault Jouannic',
    author_email='thibault@miximum.fr',
    setup_requires=('setuptools'),
    install_requires=[
        'nexmo',
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import nexmo

from django.conf import settings


def send_message(frm=None, to=None, text=None):
    """Shortcut to send a sms using libnexmo api.

    :param frm: The originator of the message
    :param to: The message's recipient
    :param text: The text message body

    Example usage:

    >>> send_message(to='+33123456789', text='My sms message body')

    """
    assert to is not None
    assert text is not None

    if frm is None:
        frm = settings.NEXMO_DEFAULT_FROM

    client = nexmo.Client(key=settings.NEXMO_API_KEY, secret=settings.NEXMO_API_SECRET)
    response = client.send_message({
        'from': frm,
        'to': to,
        'text': text
    })
    return response



import logging

from django.http import HttpResponse

from .error_messages import (NEXMO_STATUSES, UNKNOWN_STATUS,
                             NEXMO_MESSAGES, UNKNOWN_MESSAGE)


logger = logging.getLogger(__name__)


def callback(request):
    """Callback URL for Nexmo."""
    message_id = request.GET.get('messageId')
    status_id = request.GET.get('status')
    status_msg = NEXMO_STATUSES.get(status_id, UNKNOWN_STATUS)
    error_id = int(request.GET.get('err-code'))
    error_msg = NEXMO_MESSAGES.get(error_id, UNKNOWN_MESSAGE)

    logger.info(u'Nexmo callback: Sms = %s, Status = %s, message = %s' % (
        message_id,
        status_msg,
        error_msg
    ))

    # Nexmo expects a 200 response code
    return HttpResponse('')
